from ..messages import actions
from .player_actions import PlayerActions
from ..player import PlayerId

class RandomPlayerActions(PlayerActions):
    def __init__(self, id: PlayerId, seed: int): ...
    def _draw_or_trade(self) -> actions.PlayerTurnDecision: ...
    def _trade(self) -> actions.InitialTrade: ...
    def _provide_bidding(self, state) -> actions.Bidding: ...
    def _buy_or_sell(self, state) -> actions.AuctionDecision: ...
    def _send_money_to_player(self, player, amount) -> actions.SendMoney: ...
    def _respond_to_trade(self, offer) -> actions.TradeOpponentDecision: ...
    def _receive_game_update(self, update) -> actions.NoAction: ...
